@@ -7,7 +7,8 @@ boot.transitions <- function(transitions, iterations, by.stage.counts=FALSE, ...
    mat <- vector("list", t)                       ## initialize a list to store matrices
    vec <- vector("list", t)                       ## and stage vectors 
    lam <-numeric(t)                               ## and a vector for lambdas
-   for (i in 1:t)
+
+  for (i in 1:t)
    { 
       if(by.stage.counts)
       {
@@ -26,10 +27,15 @@ boot.transitions <- function(transitions, iterations, by.stage.counts=FALSE, ...
       mat[[i]] <- as.vector(A)
       lam[i]  <- max(Re(eigen(A)$values))         ## Calculate dominant eigenvalue
    }
+
+   n<-dim(A)[1]
+
+    
    boot.stage <- list(
     lambda= lam, 
-    matrix= matrix(unlist(mat), byrow=TRUE, nrow=t), ## Store one matrix  
-    vector= matrix(unlist(vec), byrow=TRUE, nrow=t)  ## and vector per row
+    matrix= matrix(unlist(mat), byrow=TRUE, nrow=t,
+          dimnames=list(1:t, paste("a", 1:n, rep(1:n,each=n), sep=""))), ## Store one matrix  
+    vector= matrix(unlist(vec), byrow=TRUE, nrow=t, dimnames=list(1:t, rownames(A)))  ## and vector per row
    )
    boot.stage
 }
